@@ -4,10 +4,11 @@ package YAML::PP::Schema;
 use B;
 use Module::Load qw//;
 
-our $VERSION = '0.015_001'; # TRIAL VERSION
+our $VERSION = '0.016_001'; # TRIAL VERSION
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 
+use Scalar::Util qw/ blessed /;
 
 sub new {
     my ($class, %args) = @_;
@@ -78,6 +79,12 @@ sub load_subschemas {
     while ($i < @schemas) {
         my $item = $schemas[ $i ];
         $i++;
+        if (blessed($item)) {
+            $item->register(
+                schema => $self,
+            );
+            next;
+        }
         my @options;
         while ($i < @schemas
             and (
@@ -105,7 +112,7 @@ sub load_subschemas {
             }
             $LOADED_SCHEMA{ $item } ||= Module::Load::load $class;
         }
-        my $tags = $class->register(
+        $class->register(
             schema => $self,
             options => \@options,
         );
@@ -316,6 +323,12 @@ sub create_sequence {
 
     my $resolvers = $self->resolvers->{sequence};
     if ($tag) {
+        if (my $equals = $resolvers->{tag}->{ $tag }) {
+            my $on_create = $equals->{on_create};
+            $on_data = $equals->{on_data};
+            $on_create and $data = $on_create->($constructor, $event);
+            return ($data, $on_data);
+        }
         if (my $matches = $resolvers->{tags}) {
             for my $match (@$matches) {
                 my ($re, $actions) = @$match;
@@ -327,12 +340,6 @@ sub create_sequence {
                 }
             }
         }
-        if (my $equals = $resolvers->{tag}->{ $tag }) {
-            my $on_create = $equals->{on_create};
-            $on_data = $equals->{on_data};
-            $on_create and $data = $on_create->($constructor, $event);
-            return ($data, $on_data);
-        }
     }
 
     return ($data, $on_data);
@@ -346,6 +353,12 @@ sub create_mapping {
 
     my $resolvers = $self->resolvers->{mapping};
     if ($tag) {
+        if (my $equals = $resolvers->{tag}->{ $tag }) {
+            my $on_create = $equals->{on_create};
+            $on_data = $equals->{on_data};
+            $on_create and $data = $on_create->($constructor, $event);
+            return ($data, $on_data);
+        }
         if (my $matches = $resolvers->{tags}) {
             for my $match (@$matches) {
                 my ($re, $actions) = @$match;
@@ -357,12 +370,6 @@ sub create_mapping {
                 }
             }
         }
-        if (my $equals = $resolvers->{tag}->{ $tag }) {
-            my $on_create = $equals->{on_create};
-            $on_data = $equals->{on_data};
-            $on_create and $data = $on_create->($constructor, $event);
-            return ($data, $on_data);
-        }
     }
 
     return ($data, $on_data);
